==> nextcloud-30.0.5.tgz: nextcloud/apps/systemtags/l10n/nl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systeemtag %1$s toegevoegd door het systeem",
    "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
    "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
    "%1$s added system tag %2$s" : "%1$s voegde systeemtag %2$s toe",
    "{actor} added system tag {systemtag}" : "{actor} voegde systeemtag {systemtag} toe",
    "System tag %1$s removed by the system" : "Systeemtag %1$s verwijderd door het systeem",
    "Removed system tag {systemtag}" : "Verwijderde systeemtag {systemtag}",
    "Removed system tag %1$s" : "Verwijderde systeemtag %1$s",
    "%1$s removed system tag %2$s" : "%1$s verwijderde systeemtag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You created system tag %1$s" : "Je creëerde systeemtag %1$s",
    "You created system tag {systemtag}" : "Je creëerde systeemtag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creëerde systeemmarkering %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creëerde systeemtag {systemtag}",
    "You deleted system tag %1$s" : "Je verwijderde systeemtag %1$s",
    "You deleted system tag {systemtag}" : "Je verwijderde systeemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem markering %2$s van het systeem",
    "{actor} deleted system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Je werkte systeemtag %2$s bij naar  %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Je werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem markering %3$s naar %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systeemtag %2$s door systeem toegevoegd aan %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Systeemtag {systemtag} is door het systeem toegevoegd aan bestand {file}",
    "You added system tag %2$s to %1$s" : "Je voegde systeemtag %2$s toe aan %1$s",
    "You added system tag {systemtag} to {file}" : "Je voegde systeemtag {systemtag} toe aan {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s voegde systeemtag %3$s toe aan %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} voegde systeemtag {systemtag} toe aan {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systeemtag %2$s door het systeem verwijderd van %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Systeemtag {systemtag} door het systeem verwijderd van {file}",
    "You removed system tag %2$s from %1$s" : "Je verwijderde systeemtag %2$s van %1$s",
    "You removed system tag {systemtag} from {file}" : "Verwijderde systeemtag {systemtag} van {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s verwijderde systeemtag %3$s van %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} verwijderde systeemtag {systemtag} van {file}",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
    "Files" : "Bestanden",
    "Tags" : "Markering",
    "Collaborative tags" : "Systeemtags",
    "Create" : "Opslaan",
    "Update" : "Update",
    "Delete" : "Verwijder",
    "Reset" : "Herstellen",
    "Loading …" : "Laden …",
    "Public" : "Standaard",
    "Restricted" : "Beschermd",
    "Invisible" : "Verborgen",
    "Manage tags" : "Berichttags",
    "Cancel" : "Annuleren",
    "Failed to load tags" : "Kon tags niet laden",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
    "Open in Files" : "Open in Bestanden",
    "No tags found" : "Geen tags gevonden",
    "Collaborative tagging functionality which shares tags among users." : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers. Perfect voor teams\n(als je een provider met een multi-tenancy installatie bent, adviseren we om deze app uit te schakelen omdat tags worden gedeeld.)",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Tag",
    "Size" : "Grootte",
    "Modified" : "Aangepast"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/systemtags/l10n/nl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systeemtag %1$s toegevoegd door het systeem",
    "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
    "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
    "%1$s added system tag %2$s" : "%1$s voegde systeemtag %2$s toe",
    "{actor} added system tag {systemtag}" : "{actor} voegde systeemtag {systemtag} toe",
    "System tag %1$s removed by the system" : "Systeemtag %1$s verwijderd door het systeem",
    "Removed system tag {systemtag}" : "Verwijderde systeemtag {systemtag}",
    "Removed system tag %1$s" : "Verwijderde systeemtag %1$s",
    "%1$s removed system tag %2$s" : "%1$s verwijderde systeemtag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You created system tag %1$s" : "Je creëerde systeemtag %1$s",
    "You created system tag {systemtag}" : "Je creëerde systeemtag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creëerde systeemmarkering %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creëerde systeemtag {systemtag}",
    "You deleted system tag %1$s" : "Je verwijderde systeemtag %1$s",
    "You deleted system tag {systemtag}" : "Je verwijderde systeemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem markering %2$s van het systeem",
    "{actor} deleted system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Je werkte systeemtag %2$s bij naar  %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Je werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem markering %3$s naar %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systeemtag %2$s door systeem toegevoegd aan %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Systeemtag {systemtag} is door het systeem toegevoegd aan bestand {file}",
    "You added system tag %2$s to %1$s" : "Je voegde systeemtag %2$s toe aan %1$s",
    "You added system tag {systemtag} to {file}" : "Je voegde systeemtag {systemtag} toe aan {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s voegde systeemtag %3$s toe aan %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} voegde systeemtag {systemtag} toe aan {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systeemtag %2$s door het systeem verwijderd van %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Systeemtag {systemtag} door het systeem verwijderd van {file}",
    "You removed system tag %2$s from %1$s" : "Je verwijderde systeemtag %2$s van %1$s",
    "You removed system tag {systemtag} from {file}" : "Verwijderde systeemtag {systemtag} van {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s verwijderde systeemtag %3$s van %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} verwijderde systeemtag {systemtag} van {file}",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
    "Files" : "Bestanden",
    "Tags" : "Markering",
    "Collaborative tags" : "Systeemtags",
    "Public" : "Standaard",
    "Restricted" : "Beschermd",
    "Invisible" : "Verborgen",
    "Search for a tag to edit" : "Zoek naar een tag om te bewerken",
    "Create" : "Opslaan",
    "Update" : "Update",
    "Delete" : "Verwijder",
    "Reset" : "Herstellen",
    "Loading …" : "Laden …",
    "Manage tags" : "Berichttags",
    "Search or create tag" : "Zoek of maak een tag",
    "Search tag" : "Zoek tag",
    "Cancel" : "Annuleren",
    "Failed to load tags" : "Kon tags niet laden",
    "Search or create collaborative tags" : "Zoek of maak een samenwerkingstags",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
    "Assigned collaborative tags" : "Samenwerkingstags toewijzen",
    "Open in Files" : "Open in Bestanden",
    "No tags found" : "Geen tags gevonden"
},
"nplurals=2; plural=(n != 1);");
